==> geoR_1.3-7.tar.gz: geoR/data/ca20.R <==
"ca20" <-
structure(list(coords = structure(c(5710, 5727, 5745, 5764, 5781, 
5799, 5817, 5837, 5873, 5907, 5925, 5943, 5961, 5681, 5698, 5734, 
5751, 5769, 5790, 5808, 5825, 5843, 5864, 5881, 5899, 5918, 5634, 
5653, 5670, 5688, 5705, 5723, 5744, 5761, 5797, 5818, 5836, 5871, 
5606, 5623, 5641, 5659, 5677, 5698, 5715, 5733, 5750, 5770, 5806, 
5825, 5541, 5559, 5576, 5595, 5613, 5631, 5651, 5668, 5686, 5704, 
5724, 5765, 5784, 5495, 5512, 5530, 5547, 5565, 5582, 5604, 5622, 
5658, 5677, 5713, 5448, 5466, 5484, 5501, 5518, 5536, 5557, 5575, 
5593, 5631, 5666, 5685, 5402, 5420, 5437, 5455, 5473, 5491, 5511, 
5529, 5547, 5584, 5638, 5355, 5373, 5391, 5409, 5427, 5445, 5466, 
5484, 5501, 5519, 5538, 5289, 5308, 5325, 5344, 5362, 5379, 5398, 
5437, 5455, 5473, 5243, 5261, 5279, 5297, 5316, 5334, 5351, 5374, 
5448, 5485, 5179, 5197, 5215, 5233, 5251, 5270, 5288, 5307, 5327, 
5363, 5437, 5131, 5150, 5169, 5186, 5204, 5222, 5240, 5258, 5283, 
5355, 5372, 5390, 5067, 5086, 5103, 5121, 5140, 5157, 5176, 5194, 
5213, 5269, 5343, 5362, 5021, 5039, 5057, 5075, 5093, 5112, 5129, 
5260, 5279, 4957, 4975, 4993, 5011, 5029, 5047, 4829, 4875, 4922, 
4969, 5015, 5062, 5109, 5161, 5254, 5347, 5394, 5441, 5487, 4891, 
4937, 5031, 5078, 5125, 5178, 5225, 5271, 5319, 5371, 5419, 5464, 
5511, 4908, 4954, 5001, 5049, 5095, 5142, 5196, 5242, 5336, 5390, 
5436, 5529, 4972, 5019, 5066, 5112, 5159, 5214, 5260, 5307, 5354, 
5407, 5500, 5545, 4943, 4989, 5036, 5083, 5129, 5176, 5230, 5277, 
5325, 5371, 5423, 5513, 5561, 4961, 5006, 5054, 5100, 5147, 5193, 
5248, 5295, 5389, 5440, 5533, 4980, 5026, 5073, 5117, 5164, 5211, 
5266, 5314, 5360, 5458, 5552, 5598, 4997, 5044, 5090, 5136, 5183, 
5231, 5284, 5330, 5377, 5475, 5615, 5016, 5061, 5108, 5155, 5201, 
5247, 5302, 5348, 5395, 5441, 5494, 4984, 5030, 5077, 5125, 5170, 
5219, 5266, 5365, 5411, 5459, 5002, 5048, 5095, 5141, 5188, 5235, 
5281, 5337, 5529, 5620, 4973, 5020, 5068, 5113, 5160, 5207, 5254, 
5302, 5354, 5447, 5639, 4990, 5037, 5084, 5131, 5177, 5225, 5270, 
5317, 5380, 5564, 5610, 5656, 4961, 5008, 5054, 5101, 5147, 5195, 
5241, 5287, 5333, 5480, 5673, 5720, 4978, 5026, 5071, 5118, 5165, 
5212, 5259, 5597, 5645, 4951, 4997, 5044, 5090, 5136, 5183), .Dim = c(178, 
2), .Dimnames = list(c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95", "96", 
"97", "98", "99", "100", "101", "102", "103", "104", "105", "106", 
"107", "108", "109", "110", "111", "112", "113", "114", "115", 
"116", "117", "118", "119", "120", "121", "122", "123", "124", 
"125", "126", "127", "128", "129", "130", "131", "132", "133", 
"134", "135", "136", "137", "138", "139", "140", "141", "142", 
"143", "144", "145", "146", "147", "148", "149", "150", "151", 
"152", "153", "154", "155", "156", "157", "158", "159", "160", 
"161", "162", "163", "164", "165", "166", "167", "168", "169", 
"170", "171", "172", "173", "174", "175", "176", "177", "178"
), c("leste", "norte"))), data = c(52, 57, 72, 74, 68, 45, 47, 
49, 38, 53, 60, 47, 34, 56, 66, 53, 43, 42, 49, 45, 53, 38, 47, 
35, 60, 45, 60, 61, 58, 44, 50, 47, 49, 46, 43, 56, 43, 50, 61, 
57, 57, 42, 41, 54, 46, 50, 43, 72, 56, 38, 64, 56, 68, 61, 50, 
47, 58, 53, 47, 36, 41, 71, 44, 68, 67, 58, 52, 64, 54, 52, 46, 
40, 39, 62, 58, 66, 50, 50, 61, 61, 58, 40, 44, 33, 28, 59, 66, 
65, 54, 66, 71, 69, 59, 43, 41, 29, 72, 49, 53, 58, 55, 54, 56, 
47, 43, 48, 47, 38, 58, 53, 52, 56, 53, 50, 47, 43, 40, 38, 58, 
55, 65, 53, 58, 42, 46, 35, 27, 58, 56, 56, 66, 58, 45, 40, 48, 
52, 31, 25, 40, 47, 42, 63, 63, 52, 39, 47, 42, 29, 37, 40, 52, 
60, 50, 57, 68, 58, 43, 30, 28, 33, 21, 39, 36, 48, 58, 66, 51, 
47, 46, 44, 35, 32, 64, 54, 62, 63, 78, 52), covariate = structure(list(
    altitude = c(6.1, 6.05, 6.3, 6.6, 6.6, 5.75, 5.35, 5.1, 5, 
    5.2, 5.05, 4.65, 4.4, 6.1, 6.2, 5.65, 5.55, 5.3, 5, 5.1, 
    4.9, 5.2, 5.1, 4.9, 4.5, 4.1, 6.35, 6.45, 6.2, 5.75, 5.5, 
    5.2, 5.2, 5.35, 5.35, 5.2, 4.9, 4, 6.2, 5.75, 5.55, 5.4, 
    5.25, 5.45, 5.55, 5.6, 5.8, 5.3, 4.7, 3.8, 6, 5.78, 5.4, 
    5.45, 5.2, 5.45, 5.5, 5.6, 5.5, 5, 5.15, 4.2, 3.6, 6.1, 5.9, 
    5.65, 5.5, 5.32, 5.55, 5.6, 5.5, 4.95, 5.4, 4, 5.9, 5.95, 
    5.75, 5.55, 5.51, 5.65, 5.64, 5.05, 5.05, 4.9, 4.5, 4.05, 
    5.9, 5.9, 5.85, 5.85, 5.85, 5.95, 5.75, 5.3, 5.1, 5, 4.35, 
    6.2, 6.25, 6.15, 6.2, 5.9, 5.85, 5.35, 5.4, 5.8, 5.9, 5.75, 
    6.1, 6.25, 6.4, 6.35, 6, 5.7, 5.38, 5.85, 5.95, 6, 6.05, 
    6.15, 6.25, 6, 5.6, 5.35, 5.2, 5.65, 6, 3.95, 6.1, 6.18, 
    6.3, 6.25, 5.6, 5.2, 5.25, 5.65, 6.05, 6.5, 3.83, 6.05, 6.33, 
    6.28, 6.1, 5.65, 5.25, 5.65, 5.95, 6.3, 4.35, 3.85, 3.79, 
    5.8, 5.9, 6.13, 6, 5.65, 5.4, 5.85, 6.05, 6.25, 5.1, 3.78, 
    3.3, 6.05, 5.8, 5.85, 5.68, 5.65, 5.83, 6.1, 4.25, 5.6, 6.3, 
    6.25, 6.1, 6.05, 5.95, 6.13), area = structure(c(3, 3, 3, 
    3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 2, 2, 2, 
    2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 
    3, 3, 3, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 
    2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 3, 3, 3, 3, 3, 
    3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 3, 
    3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 
    2, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 3, 3, 3, 3, 3, 3, 
    3, 1, 1, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 1, 1, 3, 3, 3, 3, 
    3, 3, 3, 3, 1, 1, 1, 1, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 
    3, 3, 3, 3), .Label = c("1", "2", "3"), class = "factor")), .Names = c("altitude", 
"area"), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95", "96", 
"97", "98", "99", "100", "101", "102", "103", "104", "105", "106", 
"107", "108", "109", "110", "111", "112", "113", "114", "115", 
"116", "117", "118", "119", "120", "121", "122", "123", "124", 
"125", "126", "127", "128", "129", "130", "131", "132", "133", 
"134", "135", "136", "137", "138", "139", "140", "141", "142", 
"143", "144", "145", "146", "147", "148", "149", "150", "151", 
"152", "153", "154", "155", "156", "157", "158", "159", "160", 
"161", "162", "163", "164", "165", "166", "167", "168", "169", 
"170", "171", "172", "173", "174", "175", "176", "177", "178"
), class = "data.frame"), border = structure(list(leste = c(5340, 
5590, 5990, 5990, 5780, 5590, 5350, 5150, 4920, 4920, 5150, 5250, 
5220, 5340), norte = c(5800, 5690, 5690, 5100, 4800, 4800, 4900, 
4920, 4900, 5000, 5370, 5370, 5700, 5800)), .Names = c("leste", 
"norte"), row.names = c("2", "1", "8", "11", "10", "9", "81", 
"7", "6", "5", "4", "41", "3", "22"), class = "data.frame"), 
    reg1 = structure(list(leste = c(5590, 5340, 5220, 5250, 5350, 
    5450, 5510, 5590), norte = c(5690, 5800, 5700, 5370, 5370, 
    5500, 5600, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
    "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
    reg2 = structure(list(leste = c(5990, 5590, 5350, 5450, 5510, 
    5590, 5800, 5990), norte = c(5100, 5300, 5370, 5500, 5600, 
    5690, 5690, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
    "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
    reg3 = structure(list(leste = c(5990, 5590, 5350, 5150, 4920, 
    4920, 5150, 5350, 5590, 5780), norte = c(5100, 5300, 5370, 
    5370, 5000, 4900, 4920, 4900, 4800, 4800)), .Names = c("leste", 
    "norte"), row.names = c("1", "2", "3", "4", "5", "6", "7", 
    "8", "9", "10"), class = "data.frame"), cov = structure(list(
        altitude = c(6.1, 6.05, 6.3, 6.6, 6.6, 5.75, 5.35, 5.1, 
        5, 5.2, 5.05, 4.65, 4.4, 6.1, 6.2, 5.65, 5.55, 5.3, 5, 
        5.1, 4.9, 5.2, 5.1, 4.9, 4.5, 4.1, 6.35, 6.45, 6.2, 5.75, 
        5.5, 5.2, 5.2, 5.35, 5.35, 5.2, 4.9, 4, 6.2, 5.75, 5.55, 
        5.4, 5.25, 5.45, 5.55, 5.6, 5.8, 5.3, 4.7, 3.8, 6, 5.78, 
        5.4, 5.45, 5.2, 5.45, 5.5, 5.6, 5.5, 5, 5.15, 4.2, 3.6, 
        6.1, 5.9, 5.65, 5.5, 5.32, 5.55, 5.6, 5.5, 4.95, 5.4, 
        4, 5.9, 5.95, 5.75, 5.55, 5.51, 5.65, 5.64, 5.05, 5.05, 
        4.9, 4.5, 4.05, 5.9, 5.9, 5.85, 5.85, 5.85, 5.95, 5.75, 
        5.3, 5.1, 5, 4.35, 6.2, 6.25, 6.15, 6.2, 5.9, 5.85, 5.35, 
        5.4, 5.8, 5.9, 5.75, 6.1, 6.25, 6.4, 6.35, 6, 5.7, 5.38, 
        5.85, 5.95, 6, 6.05, 6.15, 6.25, 6, 5.6, 5.35, 5.2, 5.65, 
        6, 3.95, 6.1, 6.18, 6.3, 6.25, 5.6, 5.2, 5.25, 5.65, 
        6.05, 6.5, 3.83, 6.05, 6.33, 6.28, 6.1, 5.65, 5.25, 5.65, 
        5.95, 6.3, 4.35, 3.85, 3.79, 5.8, 5.9, 6.13, 6, 5.65, 
        5.4, 5.85, 6.05, 6.25, 5.1, 3.78, 3.3, 6.05, 5.8, 5.85, 
        5.68, 5.65, 5.83, 6.1, 4.25, 5.6, 6.3, 6.25, 6.1, 6.05, 
        5.95, 6.13), area = structure(c(3, 3, 3, 3, 3, 3, 3, 
        3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 
        2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 
        3, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 
        2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 3, 3, 3, 3, 3, 
        3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 
        3, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 
        2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 3, 3, 3, 
        3, 3, 3, 3, 1, 1, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 1, 1, 
        3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 1, 1, 3, 3, 3, 3, 3, 3, 
        3, 1, 1, 3, 3, 3, 3, 3, 3), .Label = c("1", "2", "3"), class = "factor")), .Names = c("altitude", 
    "area"), row.names = c("1", "2", "3", "4", "5", "6", "7", 
    "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", 
    "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", 
    "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", 
    "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", 
    "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", 
    "58", "59", "60", "61", "62", "63", "64", "65", "66", "67", 
    "68", "69", "70", "71", "72", "73", "74", "75", "76", "77", 
    "78", "79", "80", "81", "82", "83", "84", "85", "86", "87", 
    "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", 
    "98", "99", "100", "101", "102", "103", "104", "105", "106", 
    "107", "108", "109", "110", "111", "112", "113", "114", "115", 
    "116", "117", "118", "119", "120", "121", "122", "123", "124", 
    "125", "126", "127", "128", "129", "130", "131", "132", "133", 
    "134", "135", "136", "137", "138", "139", "140", "141", "142", 
    "143", "144", "145", "146", "147", "148", "149", "150", "151", 
    "152", "153", "154", "155", "156", "157", "158", "159", "160", 
    "161", "162", "163", "164", "165", "166", "167", "168", "169", 
    "170", "171", "172", "173", "174", "175", "176", "177", "178"
    ), class = "data.frame")), .Names = c("coords", "data", "covariate", 
"border", "reg1", "reg2", "reg3", "cov"), class = "geodata")

==> geoR_1.3-10.tar.gz: geoR/data/ca20.R <==
"ca20" <-
structure(list(coords = structure(c(5710, 5727, 5745, 5764, 5781, 
5799, 5817, 5837, 5873, 5907, 5925, 5943, 5961, 5681, 5698, 5734, 
5751, 5769, 5790, 5808, 5825, 5843, 5864, 5881, 5899, 5918, 5634, 
5653, 5670, 5688, 5705, 5723, 5744, 5761, 5797, 5818, 5836, 5871, 
5606, 5623, 5641, 5659, 5677, 5698, 5715, 5733, 5750, 5770, 5806, 
5825, 5541, 5559, 5576, 5595, 5613, 5631, 5651, 5668, 5686, 5704, 
5724, 5765, 5784, 5495, 5512, 5530, 5547, 5565, 5582, 5604, 5622, 
5658, 5677, 5713, 5448, 5466, 5484, 5501, 5518, 5536, 5557, 5575, 
5593, 5631, 5666, 5685, 5402, 5420, 5437, 5455, 5473, 5491, 5511, 
5529, 5547, 5584, 5638, 5355, 5373, 5391, 5409, 5427, 5445, 5466, 
5484, 5501, 5519, 5538, 5289, 5308, 5325, 5344, 5362, 5379, 5398, 
5437, 5455, 5473, 5243, 5261, 5279, 5297, 5316, 5334, 5351, 5374, 
5448, 5485, 5179, 5197, 5215, 5233, 5251, 5270, 5288, 5307, 5327, 
5363, 5437, 5131, 5150, 5169, 5186, 5204, 5222, 5240, 5258, 5283, 
5355, 5372, 5390, 5067, 5086, 5103, 5121, 5140, 5157, 5176, 5194, 
5213, 5269, 5343, 5362, 5021, 5039, 5057, 5075, 5093, 5112, 5129, 
5260, 5279, 4957, 4975, 4993, 5011, 5029, 5047, 4829, 4875, 4922, 
4969, 5015, 5062, 5109, 5161, 5254, 5347, 5394, 5441, 5487, 4891, 
4937, 5031, 5078, 5125, 5178, 5225, 5271, 5319, 5371, 5419, 5464, 
5511, 4908, 4954, 5001, 5049, 5095, 5142, 5196, 5242, 5336, 5390, 
5436, 5529, 4972, 5019, 5066, 5112, 5159, 5214, 5260, 5307, 5354, 
5407, 5500, 5545, 4943, 4989, 5036, 5083, 5129, 5176, 5230, 5277, 
5325, 5371, 5423, 5513, 5561, 4961, 5006, 5054, 5100, 5147, 5193, 
5248, 5295, 5389, 5440, 5533, 4980, 5026, 5073, 5117, 5164, 5211, 
5266, 5314, 5360, 5458, 5552, 5598, 4997, 5044, 5090, 5136, 5183, 
5231, 5284, 5330, 5377, 5475, 5615, 5016, 5061, 5108, 5155, 5201, 
5247, 5302, 5348, 5395, 5441, 5494, 4984, 5030, 5077, 5125, 5170, 
5219, 5266, 5365, 5411, 5459, 5002, 5048, 5095, 5141, 5188, 5235, 
5281, 5337, 5529, 5620, 4973, 5020, 5068, 5113, 5160, 5207, 5254, 
5302, 5354, 5447, 5639, 4990, 5037, 5084, 5131, 5177, 5225, 5270, 
5317, 5380, 5564, 5610, 5656, 4961, 5008, 5054, 5101, 5147, 5195, 
5241, 5287, 5333, 5480, 5673, 5720, 4978, 5026, 5071, 5118, 5165, 
5212, 5259, 5597, 5645, 4951, 4997, 5044, 5090, 5136, 5183), .Dim = c(178, 
2), .Dimnames = list(c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95", "96", 
"97", "98", "99", "100", "101", "102", "103", "104", "105", "106", 
"107", "108", "109", "110", "111", "112", "113", "114", "115", 
"116", "117", "118", "119", "120", "121", "122", "123", "124", 
"125", "126", "127", "128", "129", "130", "131", "132", "133", 
"134", "135", "136", "137", "138", "139", "140", "141", "142", 
"143", "144", "145", "146", "147", "148", "149", "150", "151", 
"152", "153", "154", "155", "156", "157", "158", "159", "160", 
"161", "162", "163", "164", "165", "166", "167", "168", "169", 
"170", "171", "172", "173", "174", "175", "176", "177", "178"
), c("leste", "norte"))), data = c(52, 57, 72, 74, 68, 45, 47, 
49, 38, 53, 60, 47, 34, 56, 66, 53, 43, 42, 49, 45, 53, 38, 47, 
35, 60, 45, 60, 61, 58, 44, 50, 47, 49, 46, 43, 56, 43, 50, 61, 
57, 57, 42, 41, 54, 46, 50, 43, 72, 56, 38, 64, 56, 68, 61, 50, 
47, 58, 53, 47, 36, 41, 71, 44, 68, 67, 58, 52, 64, 54, 52, 46, 
40, 39, 62, 58, 66, 50, 50, 61, 61, 58, 40, 44, 33, 28, 59, 66, 
65, 54, 66, 71, 69, 59, 43, 41, 29, 72, 49, 53, 58, 55, 54, 56, 
47, 43, 48, 47, 38, 58, 53, 52, 56, 53, 50, 47, 43, 40, 38, 58, 
55, 65, 53, 58, 42, 46, 35, 27, 58, 56, 56, 66, 58, 45, 40, 48, 
52, 31, 25, 40, 47, 42, 63, 63, 52, 39, 47, 42, 29, 37, 40, 52, 
60, 50, 57, 68, 58, 43, 30, 28, 33, 21, 39, 36, 48, 58, 66, 51, 
47, 46, 44, 35, 32, 64, 54, 62, 63, 78, 52), covariate = structure(list(
    altitude = c(6.1, 6.05, 6.3, 6.6, 6.6, 5.75, 5.35, 5.1, 5, 
    5.2, 5.05, 4.65, 4.4, 6.1, 6.2, 5.65, 5.55, 5.3, 5, 5.1, 
    4.9, 5.2, 5.1, 4.9, 4.5, 4.1, 6.35, 6.45, 6.2, 5.75, 5.5, 
    5.2, 5.2, 5.35, 5.35, 5.2, 4.9, 4, 6.2, 5.75, 5.55, 5.4, 
    5.25, 5.45, 5.55, 5.6, 5.8, 5.3, 4.7, 3.8, 6, 5.78, 5.4, 
    5.45, 5.2, 5.45, 5.5, 5.6, 5.5, 5, 5.15, 4.2, 3.6, 6.1, 5.9, 
    5.65, 5.5, 5.32, 5.55, 5.6, 5.5, 4.95, 5.4, 4, 5.9, 5.95, 
    5.75, 5.55, 5.51, 5.65, 5.64, 5.05, 5.05, 4.9, 4.5, 4.05, 
    5.9, 5.9, 5.85, 5.85, 5.85, 5.95, 5.75, 5.3, 5.1, 5, 4.35, 
    6.2, 6.25, 6.15, 6.2, 5.9, 5.85, 5.35, 5.4, 5.8, 5.9, 5.75, 
    6.1, 6.25, 6.4, 6.35, 6, 5.7, 5.38, 5.85, 5.95, 6, 6.05, 
    6.15, 6.25, 6, 5.6, 5.35, 5.2, 5.65, 6, 3.95, 6.1, 6.18, 
    6.3, 6.25, 5.6, 5.2, 5.25, 5.65, 6.05, 6.5, 3.83, 6.05, 6.33, 
    6.28, 6.1, 5.65, 5.25, 5.65, 5.95, 6.3, 4.35, 3.85, 3.79, 
    5.8, 5.9, 6.13, 6, 5.65, 5.4, 5.85, 6.05, 6.25, 5.1, 3.78, 
    3.3, 6.05, 5.8, 5.85, 5.68, 5.65, 5.83, 6.1, 4.25, 5.6, 6.3, 
    6.25, 6.1, 6.05, 5.95, 6.13), area = structure(c(3, 3, 3, 
    3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 2, 2, 2, 
    2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 
    3, 3, 3, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 
    2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 3, 3, 3, 3, 3, 
    3, 3, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 3, 
    3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 2, 2, 
    2, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 3, 3, 3, 3, 3, 3, 
    3, 1, 1, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 1, 1, 3, 3, 3, 3, 
    3, 3, 3, 3, 1, 1, 1, 1, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 
    3, 3, 3, 3), .Label = c("1", "2", "3"), class = "factor")), .Names = c("altitude", 
"area"), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95", "96", 
"97", "98", "99", "100", "101", "102", "103", "104", "105", "106", 
"107", "108", "109", "110", "111", "112", "113", "114", "115", 
"116", "117", "118", "119", "120", "121", "122", "123", "124", 
"125", "126", "127", "128", "129", "130", "131", "132", "133", 
"134", "135", "136", "137", "138", "139", "140", "141", "142", 
"143", "144", "145", "146", "147", "148", "149", "150", "151", 
"152", "153", "154", "155", "156", "157", "158", "159", "160", 
"161", "162", "163", "164", "165", "166", "167", "168", "169", 
"170", "171", "172", "173", "174", "175", "176", "177", "178"
), class = "data.frame"), borders = structure(list(leste = c(5340, 
5590, 5990, 5990, 5780, 5590, 5350, 5150, 4920, 4920, 5150, 5250, 
5220, 5340), norte = c(5800, 5690, 5690, 5100, 4800, 4800, 4900, 
4920, 4900, 5000, 5370, 5370, 5700, 5800)), .Names = c("leste", 
"norte"), row.names = c("2", "1", "8", "11", "10", "9", "81", 
"7", "6", "5", "4", "41", "3", "22"), class = "data.frame"), 
    reg1 = structure(list(leste = c(5590, 5340, 5220, 5250, 5350, 
    5450, 5510, 5590), norte = c(5690, 5800, 5700, 5370, 5370, 
    5500, 5600, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
    "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
    reg2 = structure(list(leste = c(5990, 5590, 5350, 5450, 5510, 
    5590, 5800, 5990), norte = c(5100, 5300, 5370, 5500, 5600, 
    5690, 5690, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
    "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
    reg3 = structure(list(leste = c(5990, 5590, 5350, 5150, 4920, 
    4920, 5150, 5350, 5590, 5780), norte = c(5100, 5300, 5370, 
    5370, 5000, 4900, 4920, 4900, 4800, 4800)), .Names = c("leste", 
    "norte"), row.names = c("1", "2", "3", "4", "5", "6", "7", 
    "8", "9", "10"), class = "data.frame")),
          .Names = c("coords", "data", "covariate", 
            "borders", "reg1", "reg2", "reg3"), class = "geodata")
